=======
Credits
=======

Maintainer
----------

* Ashley Williams <ashley.williams@pg.canterbury.ac.nz>

Contributors
------------

* Yann Le Norment  <yann.lenorment@canterbury.ac.nz>
* Adrien Aucher

Want to contribute? See: CONTRIBUTING.rst

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
